@@ -10,8 +10,7 @@ from sensenet.constants import CATEGORICAL, IMAGE_PATH, BOUNDING_BOX
 from sensenet.accessors import get_image_shape
 from sensenet.load import load_points
 from sensenet.models.image import pretrained_image_model, image_feature_extractor
-from sensenet.models.image import image_layers, image_model
-from sensenet.models.image import get_pretrained_network
+from sensenet.models.image import image_layers, get_pretrained_network
 from sensenet.models.settings import Settings
 from sensenet.preprocess.image import get_image_reader_fn
 
@@ -94,8 +93,23 @@ def detect_bounding_boxes(network_name, nboxes, class_list, threshold):
 
     for pred in [file_pred, pixel_pred]:
         boxes, scores, classes = pred
+
         assert len(boxes) == len(scores) == nboxes, len(boxes)
         assert sorted(set(classes)) == sorted(class_list), classes
 
 def test_tinyyolov4():
     detect_bounding_boxes('tinyyolov4', 5, [0, 53], 0.4)
+
+def test_scaling():
+    detector = create_image_model('tinyyolov4', 0.5, 'file')
+    pred = detector.predict([['strange_car.png']])
+
+    boxes, scores, classes = pred
+
+    assert 550 < boxes[0][0] < 600, boxes[0]
+    assert 220 < boxes[0][1] < 270, boxes[0]
+    assert 970 < boxes[0][2] < 1020, boxes[0]
+    assert 370 < boxes[0][3] < 420, boxes[0]
+
+    assert scores[0] > 0.9
+    assert classes[0] == 2
